@@ -1,9 +1,9 @@
-from Bubot.Core.CatalogObjApi import CatalogObjApi
+from Bubot.Core.ObjApi import ObjApi
 # from bubot.Helpers.Сryptography.SignedData import SignedData
 from BubotObj.User.User import User
 
 
-class UserApi(CatalogObjApi):
+class UserApi(ObjApi):
     name = "User"
     handler = User
 
